#
# spec file for package fclones
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fclones
Version:        0.34.0
Release:        1.1
Summary:        Finds duplicate, unique, under- or over-replicated files
License:        MIT
URL:            https://github.com/pkolaczk/%{name}
Source0:        %{name}-%{version}.tar
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  rust >= 1.45.0

%description
A simple command-line utility program that finds duplicate, unique, under- or over-replicated files.
Contrary to fdupes or rdfind, %{name} processes files in parallel, which makes it very efficient on SSDs.
%{name} communicates through standard Unix streams and it can write reports in human- and machine-friendly formats,
therefore you can easily combine it with other tools.

%prep
%setup -qa1
install -D -m 644 %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name} %{buildroot}%{_bindir}/%{name}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Mon Dec  4 2023 Michael Vetter <mvetter@suse.com>
- Update to version 0.34.0:
  * New option one-fs #244
  * Downgrade builder image to Debian 10 (buster), remove unneeded
    pkgs #247
* Sun Oct 24 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to version 0.17.0:
  * Add examples to --help
  * Reflink: always remove temporary files
  * Minor help text tweaks.
  * Implement `fclones dedupe` command
  * Improve `with_dir` test util
  * Fix too aggressive config validation
  * Fix documentation on escaping in path globs
  * Option to not count files in the same root dir as dupes
  * Fix comments after find-and-replace gone bad
  * Make group output deterministic with existing hardlinks
* Tue Sep 14 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to version 0.15.0:
  * Implement `fclones move` command
  * Add homepage to the package manifest
  * Don't scan sysfs on startup
  * Small improvements (#68)
* Sun Aug 29 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to version 0.13.0:
  * Fix unit tests that require file creation time metadata
  * Update documentation on json support in report processing
  * Fix clippy lints - remove unneeded references
  * Automatically detect input report format
  * Implement JsonReportReader
  * Update dependencies
  * Pluggable report readers
* Mon Jun 21 2021 idesmi@protonmail.com
- Update to version 0.12.3:
  * Add *.iml to gitignore
  * Fix group --stdin option
* Wed Jun  9 2021 idesmi@protonmail.com
- Update to version 0.12.2:
  * Bump up version to 0.12.2
  * Accept report lines ended with CRLF (Windows) Interrupt processing of report immediately on the first error
  * Update benchmarks
  * Increase default number of threads for SSD thread-pool
  * Update dependencies
  * Fix build on windows
  * Fix unused import
  * Deduplicate documentation (README.md)
  * Remove leftover println
  * Fix invalid default value for --format
* Sun Apr 18 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to 0.11.0
  - all directories are now scanned recursively if not specified otherwise (--depth 0)
  - input paths are validated before running
* Fri Apr 16 2021 Enrico Belleri <idesmi@protonmail.com>
- Update to 0.10.2
  - Entries are now sorted on inode number, slightly improving performance on HDDs
* Sat Apr 10 2021 Enrico Belleri <idesmi@protonmail.com>
- initial package @ d619ecccf1fc5b18313789b6e05b43878d8a73b2
